# DatasetToMigrate

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | name of dataset | [default to '']
**namespace** | **str** | namespace of dataset | [default to '']
**path** | **str** | path to migrate | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


